aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/staging/comedi/drivers/s526.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/staging/comedi/drivers/s526.c')
-rw-r--r--drivers/staging/comedi/drivers/s526.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/comedi/drivers/s526.c b/drivers/staging/comedi/drivers/s526.c
index 51ff5a7..d388149 100644
--- a/drivers/staging/comedi/drivers/s526.c
+++ b/drivers/staging/comedi/drivers/s526.c
@@ -210,14 +210,14 @@ typedef struct {
#define devpriv ((s526_private *)dev->private)
/*
* The comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains
* the device code.
*/
static int s526_attach(struct comedi_device * dev, comedi_devconfig * it);
static int s526_detach(struct comedi_device * dev);
-static comedi_driver driver_s526 = {
+static struct comedi_driver driver_s526 = {
driver_name:"s526",
module:THIS_MODULE,
attach:s526_attach,
@@ -210,14 +210,14 @@ typedef struct {
#define devpriv ((s526_private *)dev->private)
/*
- * The comedi_driver structure tells the Comedi core module
+ * The struct comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains